%define lib64arches	x86_64 

%ifarch %lib64arches
    %define _lib lib64
%else
    %define _lib lib
%endif

%define _prefix /usr
%define _libdir %_prefix/%_lib
%define _bindir %_prefix/bin
%define _sysconfdir /etc
%define _datadir /usr/share
%define _defaultdocdir %_datadir/doc
%define _localstatedir /var
%define _infodir %_datadir/info

%if %{?apply_patches:0}%{?!apply_patches:1}
%define apply_patches %(for p in `grep '^Patch.*:' "%{_specdir}/rpm.spec" | cut -d':' -f2-`; do echo "patch -p1 -F0 -i %{_sourcedir}/$p"; done )
%endif

# Define directory which holds rpm config files, and some binaries actually
# NOTE: it remains */lib even on lib64 platforms as only one version
#       of rpm is supported anyway, per architecture
%define rpmdir %{_prefix}/lib/rpm

%if %{?mklibname:0}%{?!mklibname:1}
%define mklibname(ds)  %{_lib}%{1}%{?2:%{2}}%{?3:_%{3}}%{-s:-static}%{-d:-devel}
%endif

%if %{?distsuffix:0}%{?!distsuffix:1}
%define distsuffix .mga
%endif

%if %{?mkrel:0}%{?!mkrel:1}
%define mkrel(c:) %{-c: 0.%{-c*}.}%{1}%{?distsuffix:%distsuffix}%{?!distsuffix:.mga}%{?mageia_release:%mageia_release}%{?subrel:.%subrel}
%endif

%if %{?mips:0}%{?!mips:1}
%define mips		mips mipsel mips32 mips32el mips64 mips64el
%endif

%if %{?pyver:0}%{?!pyver:1}
%define pyver %(python -V 2>&1 | cut -f2 -d" " | cut -f1,2 -d".")
%endif

%define __find_requires %{rpmdir}/%{_real_vendor}/find-requires %{?buildroot:%{buildroot}} %{?_target_cpu:%{_target_cpu}}
%define __find_provides %{rpmdir}/%{_real_vendor}/find-provides

#define snapver		beta1
%define rpmversion	4.11.0.1
%define srcver          %{rpmversion}%{?snapver:-%{snapver}}
%define libver		4.10
%define libmajor	3
%define libmajorsign    1
%define release		%mkrel %{?snapver:0.%{snapver}.}1
%define librpmname      %mklibname rpm  %{libmajor}
%define librpmnamedevel %mklibname -d rpm
%define librpmsign      %mklibname rpmsign %{libmajor}
%define librpmbuild     %mklibname rpmbuild %{libmajor}

%define buildpython 1
%define rpmsetup_version 1.34

%define builddebug 0
%{?_with_debug:%define builddebug 1}

%{?_with_python:%define buildpython 1}
%{?_without_python:%define buildpython 0}

# disable plugins initially
%define buildplugins 0
%{?_with_plugins:%define buildplugins 1}

Summary:	The RPM package management system
Name:		rpm
Epoch:		1
Version:        %{rpmversion}
Release:	%{release}
Group:		System/Packaging
Source:		http://www.rpm.org/releases/rpm-%{libver}.x/rpm-%{srcver}.tar.bz2
# Add some undocumented feature to gendiff
# Send upstream ? drop ?
Patch17:	rpm-4.4.2.2-gendiff-improved.patch

# if %post of foo-2 fails,
# or if %preun of foo-1 fails,
# or if %postun of foo-1 fails,
# => foo-1 is not removed, so we end up with both packages in rpmdb
# this patch makes rpm ignore the error in those cases
# failing %pre must still make the rpm install fail (mdv #23677)
#
# (nb: the exit code for pretrans/posttrans & trigger/triggerun/triggerpostun
#       scripts is ignored with or without this patch)
# Needed for urpmi testsuite:
Patch22:        rpm-4.9.0-non-pre-scripts-dont-fail.patch

# (fredl) add loging facilities through syslog (pushed upstream, might be replaced by a rpm pluging in 4.11):
Patch31:	rpm-4.9.0-syslog.patch

# - force /usr/lib/rpm/mageia/rpmrc instead of /usr/lib/rpm/<vendor>/rpmrc
# - read /usr/lib/rpm/mageia/rpmpopt (not only /usr/lib/rpm/rpmpopt)
# if we deprecated the use of rpm -ba , ...,  we can get rid of this patch
Patch64:    rpm-4.9.1.1-mageia-rpmrc-rpmpopt.patch

# In original rpm, -bb --short-circuit does not work and run all stage
# From popular request, we allow to do this
# http://qa.mandriva.com/show_bug.cgi?id=15896
Patch70:	rpm-4.9.1-bb-shortcircuit.patch

# don't conflict for doc files
# (to be able to install lib*-devel together with lib64*-devel even if they have conflicting manpages)
Patch83: rpm-4.11.0-no-doc-conflicts.patch

# Fix http://qa.mandriva.com/show_bug.cgi?id=19392
# (is this working??)
Patch84: rpm-4.4.2.2-rpmqv-ghost.patch

# Fix diff issue when buildroot contains some "//"
Patch111: rpm-check-file-trim-double-slash-in-buildroot.patch

# [Dec 2008] macrofiles from rpmrc does not overrides MACROFILES anymore
# Upstream 4.11 will have /usr/lib/rpm/macros.d:
Patch114: rpm-4.9.0-read-macros_d-dot-macros.patch

# [pixel] without this patch, "rpm -e" or "rpm -U" will need to stat(2) every dirnames of
# files from the package (eg COPYING) in the db. This is quite costly when not in cache 
# (eg on a test here: >300 stats, and so 3 seconds after a "echo 3 > /proc/sys/vm/drop_caches")
# this breaks urpmi test case test_rpm_i_fail('gd') in superuser--file-conflicts.t,
# but this is bad design anyway
#Patch124: rpm-4.6.0-rc1-speedup-by-not-checking-same-files-with-different-paths-through-symlink.patch

# [from SuSE] handle "Suggests" via RPMTAG_SUGGESTSNAME
Patch133: rpm-4.10.0-weakdeps.patch
Patch134: extcond.diff

# (from Turbolinux) remove a wrong check in case %_topdir is /RPM (ie when it is short)
# Panu said: "To my knowledge this is a true technical limitation of the
# implementation: as long as debugedit can just overwrite data in the elf
# sections things keep relatively easy, but if dest_dir is longer than the
# original directory, debugedit would have to expand the whole elf file. Which
# might be technically possible but debugedit currently does not even try to."
Patch135: rpm-4.9.0-fix-debugedit.patch

# without this patch, "#%define foo bar" is surprisingly equivalent to "%define foo bar"
# with this patch, "#%define foo bar" is a fatal error
# Bug still valid => Send upstream for review.
Patch145: rpm-forbid-badly-commented-define-in-spec.patch

# cf http://wiki.mandriva.com/en/Rpm_filetriggers
# Will be allowed to be dropped when "Collection" won't be experimental anymore.
Patch146: rpm-4.9.1.1-filetriggers.patch

# add two fatal errors (during package build)
# Useful ? to drop ?
#Patch147: rpm-rpmbuild-check-useless-tags-in-non-existant-binary-packages.patch

# (nb: see the patch for more info about this issue)
#Patch151: rpm-4.6.0-rc1-protect-against-non-robust-futex.patch

Patch157: rpm-4.10.1-introduce-_after_setup-which-is-called-after-setup.patch
#Patch158: introduce-_patch-and-allow-easy-override-when-the-p.patch
Patch159: introduce-apply_patches-and-lua-var-patches_num.patch

Patch1007: rpm-4.6.0-rc3-xz-support.patch

# Prevents $DOCDIR from being wiped out when using %%doc <fileinbuilddir>,
# as this breaks stuff that installs files to $DOCDIR during %%install
#Patch1008: rpm-4.6.0-rc3-no_rm_-rf_DOCDIR.patch

# Turbolinux patches
# Crusoe CPUs say that their CPU family is "5" but they have enough features for i686.
Patch2003: rpm-4.4.2.3-rc1-transmeta-crusoe-is-686.patch

Patch2006: rpm-4.10.0-setup-rubygems.patch

# (tv) fix tests:
Patch2100: rpm-4.10.0-fix-testsuite.diff

Patch3000: mips_macros.patch
Patch3002: mips_define_isa_macros.patch
Patch3003: rpm_arm_mips_isa_macros.patch
Patch3004: rpm_add_armv5tl.patch

# when using fakechroot, make sure that testsuite pathes are against /
# and not full path
Patch3005: rpm-4.10-fix-testsuite-pathes.patch
#
# Fedora patches
# Patches 41xx are already in upstream and are 1xx in FC
#
# (tv) Temporary Patch to provide support for updates (FC):
Patch3500: rpm-4.10.90-rpmlib-filesystem-check.patch
# (tv) Compressed debuginfo support (UPSTREAM):
Patch3501: rpm-4.10.0-dwz-debuginfo.patch
# (tv) Mini debuginfo support (UPSTREAM):
Patch3502: rpm-4.10.0-minidebuginfo.patch

# (tv) merge mga stuff from rpm-setup:
Patch4000: rpm-4.10.0-find-debuginfo__mga-cfg.diff
# (tv) fix aborting when ordering empty transactions:
Patch4006: fix-order-on-empty-transactions.diff


License:	GPLv2+
BuildRequires:	autoconf
BuildRequires:	zlib-devel
BuildRequires:  bzip2-devel
BuildRequires:	liblzma-devel >= 5
BuildRequires:	automake
BuildRequires:	elfutils-devel
BuildRequires:	libbeecrypt-devel
BuildRequires:	ed
BuildRequires:	gettext-devel
BuildRequires:  libsqlite3-devel
BuildRequires:  db5.3-devel
BuildRequires:  neon-devel
BuildRequires:	popt-devel
BuildRequires:	nss-devel
BuildRequires:	magic-devel
BuildRequires:  rpm-%{_real_vendor}-setup-build %{?rpmsetup_version:>= %{rpmsetup_version}}
BuildRequires:  readline-devel
BuildRequires:	ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  lua5.1-devel
BuildRequires:  libcap-devel
# Needed for doc
#BuildRequires:	graphviz
BuildRequires:	tetex
%if %buildpython
BuildRequires:	python-devel
%endif
# for testsuite:
BuildRequires: fakechroot

Requires:	bzip2 >= 0.9.0c-2
Requires:	xz
Requires:	cpio
Requires:	gawk
Requires:	glibc >= 2.1.92
Requires:	mktemp
Requires:	setup >= 2.2.0-8
Requires:	rpm-%{_real_vendor}-setup >= 1.85
Requires:	update-alternatives
Requires:	%librpmname = %epoch:%version-%release
URL:            http://rpm.org/
%define         git_url        http://rpm.org/git/rpm.git
Requires(pre):		rpm-helper
Requires(pre):		coreutils
Requires(postun):	rpm-helper

Conflicts: perl-URPM < 4.0-2.mga3
Conflicts: jpackage-utils < 1:1.7.5-17

%description
RPM is a powerful command line driven package management system capable of
installing, uninstalling, verifying, querying, and updating software packages.
Each software package consists of an archive of files along with information
about the package like its version, a description, etc.

%package   -n %librpmbuild
Summary:   Libraries for building and signing RPM packages
Group:     System/Libraries
Obsoletes: rpm-build-libs%{_isa} < %{version}-%{release}
Provides: rpm-build-libs%{_isa} = %{version}-%{release}

%description -n %librpmbuild
This package contains the RPM shared libraries for building and signing
packages.

%package  -n %librpmsign
Summary:  Libraries for building and signing RPM packages
Group:    System/Libraries

%description -n %librpmsign
This package contains the RPM shared libraries for building and signing
packages.

%package -n %librpmname
Summary:  Library used by rpm
Group:	  System/Libraries
Provides: librpm = %version-%release

%description -n %librpmname
RPM is a powerful command line driven package management system capable of
installing, uninstalling, verifying, querying, and updating software packages.
This package contains common files to all applications based on rpm.

%package -n %librpmnamedevel
Summary:	Development files for applications which will manipulate RPM packages
Group:		Development/C
Requires:	rpm = %epoch:%{version}-%{release}
Provides:	librpm-devel = %version-%release
Provides:   	rpm-devel = %version-%release
Requires:       %librpmname = %epoch:%version-%release
Requires:       %librpmbuild = %epoch:%version-%release
Requires:       %librpmsign = %epoch:%version-%release

%description -n %librpmnamedevel
This package contains the RPM C library and header files.  These
development files will simplify the process of writing programs
which manipulate RPM packages and databases and are intended to make
it easier to create graphical package managers or any other tools
that need an intimate knowledge of RPM packages in order to function.

This package should be installed if you want to develop programs that
will manipulate RPM packages and databases.

%package build
Summary:	Scripts and executable programs used to build packages
Group:		System/Packaging
Requires:	autoconf
Requires:	automake
Requires:	file
Requires:	gcc-c++
# We need cputoolize & amd64-* alias to x86_64-* in config.sub
Requires:	libtool-base
Requires:	patch
Requires:	make
Requires:	tar
Requires:	unzip
Requires:	elfutils
Requires:	perl(CPAN::Meta) >= 2.112.150
Requires:	perl(ExtUtils::MakeMaker) >= 6.570_700
Requires:       perl(YAML::Tiny)
Requires:	rpm = %epoch:%{version}-%{release}
Requires:	rpm-%{_real_vendor}-setup-build %{?rpmsetup_version:>= %{rpmsetup_version}}

%description build
This package contains scripts and executable programs that are used to
build packages using RPM.

%package sign
Summary: Package signing support
Group:   System/Base

%description sign
This package contains support for digitally signing RPM packages.

%if %buildpython
%package -n python-rpm
Summary:	Python bindings for apps which will manipulate RPM packages
Group:		Development/Python
Requires:	rpm = %epoch:%{version}-%{release}

%description -n python-rpm
The rpm-python package contains a module which permits applications
written in the Python programming language to use the interface
supplied by RPM (RPM Package Manager) libraries.

This package should be installed if you want to develop Python
programs that will manipulate RPM packages and databases.
%endif

%prep
%setup -q -n %name-%srcver
%apply_patches

%build
autoreconf

%if %builddebug
RPM_OPT_FLAGS=-g
%endif
export CPPFLAGS="$CPPFLAGS `pkg-config --cflags nss`"
CFLAGS="$RPM_OPT_FLAGS -fPIC" CXXFLAGS="$RPM_OPT_FLAGS -fPIC" \
    %configure2_5x \
        --enable-nls \
        --enable-python \
        --enable-sqlite3 \
        --without-javaglue \
%if %builddebug
        --enable-debug \
%endif
        --with-external-db \
%if %buildpython
        --with-python=%{pyver} \
%else
        --without-python \
%endif
%if ! %buildplugins
        --disable-plugins \
%endif
        --with-glob \
        --without-selinux \
        --without-apidocs \
        --with-cap

%make

%install
rm -rf $RPM_BUILD_ROOT

make DESTDIR=%buildroot install

find $RPM_BUILD_ROOT -name "*.la"|xargs rm -f

# Save list of packages through cron
mkdir -p ${RPM_BUILD_ROOT}/etc/cron.daily
install -m 755 scripts/rpm.daily ${RPM_BUILD_ROOT}/etc/cron.daily/rpm

mkdir -p ${RPM_BUILD_ROOT}/etc/logrotate.d
install -m 644 scripts/rpm.log ${RPM_BUILD_ROOT}/etc/logrotate.d/rpm

mkdir -p $RPM_BUILD_ROOT/var/lib/rpm
for dbi in \
	Basenames Conflictname Dirnames Group Installtid Name Providename \
	Provideversion Removetid Requirename Requireversion Triggername \
	Obsoletename Packages Sha1header Sigmd5 __db.001 __db.002 \
	__db.003 __db.004 __db.005 __db.006 __db.007 __db.008 __db.009
do
    touch $RPM_BUILD_ROOT/var/lib/rpm/$dbi
done

test -d doc-copy || mkdir doc-copy
rm -rf doc-copy/*
ln -f doc/manual/* doc-copy/
rm -f doc-copy/Makefile*

mkdir -p $RPM_BUILD_ROOT/var/spool/repackage

mkdir -p %buildroot%_sysconfdir/rpm/macros.d
cat > %buildroot%_sysconfdir/rpm/macros <<EOF
# Put your own system macros here
# usually contains 

# Set this one according your locales
# %%_install_langs

EOF

%{rpmdir}/%{_host_vendor}/find-lang.pl $RPM_BUILD_ROOT %{name}

%check
make check

%pre
/usr/share/rpm-helper/add-user rpm $1 rpm /var/lib/rpm /bin/false

rm -rf /usr/lib/rpm/*-mandrake-*
rm -rf /usr/lib/rpm/*-%{_real_vendor}-*


%post
# nuke __db.00? when updating to this rpm
rm -f /var/lib/rpm/__db.00?

if [ ! -f /var/lib/rpm/Packages ]; then
    /bin/rpm --initdb
fi

%postun
/usr/share/rpm-helper/del-user rpm $1 rpm

%define	rpmattr		%attr(0755, rpm, rpm)

%files -f %{name}.lang
%defattr(-,root,root)
%doc GROUPS CHANGES doc/manual/[a-z]*
%attr(0755,rpm,rpm) /bin/rpm
%attr(0755, rpm, rpm) %{_bindir}/rpm2cpio
%attr(0755, rpm, rpm) %{_bindir}/gendiff
%attr(0755, rpm, rpm) %{_bindir}/rpmdb
%attr(0755, rpm, rpm) %{_bindir}/rpmkeys
%attr(0755, rpm, rpm) %{_bindir}/rpmgraph
%attr(0755, rpm, rpm) %{_bindir}/rpmquery
%attr(0755, rpm, rpm) %{_bindir}/rpmverify

%dir %{_localstatedir}/spool/repackage
%dir %{rpmdir}
%dir /etc/rpm
%config(noreplace) /etc/rpm/macros
%dir /etc/rpm/macros.d
%attr(0755, rpm, rpm) %{rpmdir}/config.guess
%attr(0755, rpm, rpm) %{rpmdir}/config.sub
%attr(0755, rpm, rpm) %{rpmdir}/rpmdb_*
%attr(0644, rpm, rpm) %{rpmdir}/macros
%attr(0755, rpm, rpm) %{rpmdir}/mkinstalldirs
%attr(0755, rpm, rpm) %{rpmdir}/rpm.*
%attr(0644, rpm, rpm) %{rpmdir}/rpmpopt*
%attr(0644, rpm, rpm) %{rpmdir}/rpmrc
%attr(0755, rpm, rpm) %{rpmdir}/elfdeps
%attr(0755, rpm, rpm) %{rpmdir}/script.req
%exclude %{rpmdir}/tcl.req

%rpmattr	%{rpmdir}/rpm2cpio.sh
%rpmattr	%{rpmdir}/tgpg

%dir %attr(   -, rpm, rpm) %{rpmdir}/fileattrs
%attr(0644, rpm, rpm) %{rpmdir}/fileattrs/*.attr

%dir %attr(   -, rpm, rpm) %{rpmdir}/platform/
%ifarch %{ix86} x86_64
%attr(   -, rpm, rpm) %{rpmdir}/platform/i*86-*
%attr(   -, rpm, rpm) %{rpmdir}/platform/athlon-*
%attr(   -, rpm, rpm) %{rpmdir}/platform/pentium*-*
%attr(   -, rpm, rpm) %{rpmdir}/platform/geode-*
%else
%exclude %{rpmdir}/platform/i*86-linux/macros
%exclude %{rpmdir}/platform/athlon-linux/macros
%exclude %{rpmdir}/platform/pentium*-linux/macros
%exclude %{rpmdir}/platform/geode-linux/macros
%endif
%ifarch x86_64
%attr(   -, rpm, rpm) %{rpmdir}/platform/amd64-*
%attr(   -, rpm, rpm) %{rpmdir}/platform/x86_64-*
%attr(   -, rpm, rpm) %{rpmdir}/platform/ia32e-*
%else
%exclude %{rpmdir}/platform/amd64-linux/macros
%exclude %{rpmdir}/platform/ia32e-linux/macros
%exclude %{rpmdir}/platform/x86_64-linux/macros
%endif
%ifarch %arm
%attr(   -, rpm, rpm) %{rpmdir}/platform/arm*
%else
%exclude %{rpmdir}/platform/arm*/macros
%endif
%ifarch %mips
%attr(   -, rpm, rpm) %{rpmdir}/platform/mips*
%endif
%attr(   -, rpm, rpm) %{rpmdir}/platform/noarch*
# new in 4.10.0:
%exclude %{rpmdir}/platform/alpha*-linux/macros
%exclude %{rpmdir}/platform/sparc*-linux/macros
%exclude %{rpmdir}/platform/ia64*-linux/macros
%exclude %{rpmdir}/platform/ppc*-linux/macros
%exclude %{rpmdir}/platform/s390*-linux/macros
%exclude %{rpmdir}/platform/sh*-linux/macros



%{_mandir}/man[18]/*.[18]*
%lang(pl) %{_mandir}/pl/man[18]/*.[18]*
%lang(ru) %{_mandir}/ru/man[18]/*.[18]*
%lang(ja) %{_mandir}/ja/man[18]/*.[18]*
%lang(sk) %{_mandir}/sk/man[18]/*.[18]*
%lang(fr) %{_mandir}/fr/man[18]/*.[18]*
%lang(ko) %{_mandir}/ko/man[18]/*.[18]*

%config(noreplace,missingok)	/etc/cron.daily/rpm
%config(noreplace,missingok)	/etc/logrotate.d/rpm

%attr(0755, rpm, rpm)	%dir %_localstatedir/lib/rpm

%define	rpmdbattr %attr(0644, rpm, rpm) %verify(not md5 size mtime) %ghost %config(missingok,noreplace)

%rpmdbattr	/var/lib/rpm/Basenames
%rpmdbattr	/var/lib/rpm/Conflictname
%rpmdbattr	/var/lib/rpm/__db.0*
%rpmdbattr	/var/lib/rpm/Dirnames
%rpmdbattr	/var/lib/rpm/Group
%rpmdbattr	/var/lib/rpm/Installtid
%rpmdbattr	/var/lib/rpm/Name
%rpmdbattr	/var/lib/rpm/Obsoletename
%rpmdbattr	/var/lib/rpm/Packages
%rpmdbattr	/var/lib/rpm/Providename
%rpmdbattr	/var/lib/rpm/Provideversion
%rpmdbattr	/var/lib/rpm/Removetid
%rpmdbattr	/var/lib/rpm/Requirename
%rpmdbattr	/var/lib/rpm/Requireversion
%rpmdbattr	/var/lib/rpm/Sha1header
%rpmdbattr	/var/lib/rpm/Sigmd5
%rpmdbattr	/var/lib/rpm/Triggername

%files build
%defattr(-,root,root)
%doc CHANGES
%doc doc-copy/*
%rpmattr	%{_bindir}/rpmbuild
%rpmattr        %{_bindir}/rpmspec
%rpmattr	%{_prefix}/lib/rpm/brp-*
%rpmattr	%{_prefix}/lib/rpm/check-files
%rpmattr	%{_prefix}/lib/rpm/debugedit
%rpmattr	%{_prefix}/lib/rpm/desktop-file.prov 
%rpmattr	%{_prefix}/lib/rpm/find-debuginfo.sh
%rpmattr	%{_prefix}/lib/rpm/find-lang.sh
%rpmattr	%{_prefix}/lib/rpm/find-provides
%rpmattr	%{_prefix}/lib/rpm/find-requires
%rpmattr	%{_prefix}/lib/rpm/fontconfig.prov
%rpmattr	%{_prefix}/lib/rpm/perldeps.pl
%rpmattr	%{_prefix}/lib/rpm/perl.prov
%rpmattr	%{_prefix}/lib/rpm/perl.req

%rpmattr	%{_prefix}/lib/rpm/check-buildroot
%rpmattr	%{_prefix}/lib/rpm/check-prereqs
%rpmattr	%{_prefix}/lib/rpm/check-rpaths
%rpmattr	%{_prefix}/lib/rpm/check-rpaths-worker
%rpmattr	%{_prefix}/lib/rpm/libtooldeps.sh
%rpmattr	%{_prefix}/lib/rpm/macros.perl
%rpmattr	%{_prefix}/lib/rpm/macros.php
%rpmattr	%{_prefix}/lib/rpm/macros.python
%rpmattr	%{_prefix}/lib/rpm/mono-find-provides
%rpmattr	%{_prefix}/lib/rpm/mono-find-requires
%rpmattr	%{_prefix}/lib/rpm/ocaml-find-provides.sh
%rpmattr	%{_prefix}/lib/rpm/ocaml-find-requires.sh
%rpmattr	%{_prefix}/lib/rpm/osgideps.pl
%rpmattr	%{_prefix}/lib/rpm/pkgconfigdeps.sh

%rpmattr	%{_prefix}/lib/rpm/rpmdeps
%rpmattr        %{_prefix}/lib/rpm/pythondeps.sh


%{_mandir}/man8/rpmbuild.8*
%{_mandir}/man8/rpmdeps.8*

%if %buildpython
%files -n python-rpm
%defattr(-,root,root)
%{_libdir}/python*/site-packages/rpm
%endif

%files -n %librpmname
%defattr(-,root,root)
%{_libdir}/librpm.so.%{libmajor}*
%{_libdir}/librpmio.so.%{libmajor}*
%if %{with plugins}
%{_libdir}/rpm-plugins
%endif

%files -n %librpmbuild
%{_libdir}/librpmbuild.so.%{libmajor}*

%files -n %librpmsign
%{_libdir}/librpmsign.so.%{libmajorsign}*

%files sign
%defattr(-,root,root)
%{_bindir}/rpmsign
%{_mandir}/man8/rpmsign.8*

%files -n %librpmnamedevel
%defattr(-,root,root)
%{_includedir}/rpm
%{_libdir}/librpm.so
%{_libdir}/librpmio.so
%{_libdir}/librpmbuild.so
%{_libdir}/librpmsign.so
%{_libdir}/pkgconfig/rpm.pc



%changelog

* Sun Feb 03 2013 tv <tv> 1:4.11.0.1-1.mga3
+ Revision: 394238
- reset mkrel

* Fri Feb 01 2013 tv <tv> 1:4.11.0.1-9.mga3
+ Revision: 393936
- new release
- drop patch 4004
- rediff patch 3500

* Tue Jan 22 2013 fwang <fwang> 1:4.11.0-0.beta1.9.mga3
+ Revision: 390713
- update rpm group

* Mon Jan 14 2013 umeabot <umeabot> 1:4.11.0-0.beta1.8.mga3
+ Revision: 380447
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 01 2013 tv <tv> 1:4.11.0-0.beta1.7.mga3
+ Revision: 337028
- switch debug packages from foobar-debug to foobar-debuginfo

* Sun Dec 23 2012 tv <tv> 1:4.11.0-0.beta1.6.mga3
+ Revision: 334395
- submit to core/release

* Tue Dec 18 2012 tv <tv> 1:4.11.0-0.beta1.5.mga3
+ Revision: 332644
- restore check for /usr move (was wrongly removed)

* Tue Dec 18 2012 tv <tv> 1:4.11.0-0.beta1.4.mga3
+ Revision: 332323
- fix abort while ordering empty transactions

* Mon Dec 17 2012 tv <tv> 1:4.11.0-0.beta1.3.mga3
+ Revision: 332188
- revert upstream debug -> debuginfo rename

* Mon Dec 17 2012 tv <tv> 1:4.11.0-0.beta1.2.mga3
+ Revision: 332169
- patch 83: plug memory leaks

* Mon Dec 17 2012 tv <tv> 1:4.11.0-0.beta1.1.mga3
+ Revision: 332065
- new release
- drop merged patches 3001 3500 4001 4002 & 4003
- rediff patches 83 & 145

* Sun Dec 09 2012 tv <tv> 1:4.10.2-1.mga3
+ Revision: 329045
- patch 4003: build fix
- new release
- drop patches 3503 & 4003 (merged)
- rediff patch 3002

* Thu Dec 06 2012 tv <tv> 1:4.10.1-6.mga3
+ Revision: 327271
- unbreak --setperms (RhBug:881835) (regression introduced in rpm >= 4.10
- make traversing rpmdb through NEVRA more robust

* Sat Dec 01 2012 wally <wally> 1:4.10.1-5.mga3
+ Revision: 324218
- restore and rediff patch 157 (introduce-_after_setup-which-is-called-after-setup.patch), calling rpmbuild or bm with option '--with git_repository' is broken without this patch

* Thu Oct 18 2012 tv <tv> 1:4.10.1-4.mga3
+ Revision: 308048
- enhance debugedit message

* Wed Oct 17 2012 tv <tv> 1:4.10.1-3.mga3
+ Revision: 307768
- upload to core/release

* Thu Oct 11 2012 tv <tv> 1:4.10.1-2.mga3
+ Revision: 304675
- patch 5303: fix hardlink checking regression

* Wed Oct 03 2012 tv <tv> 1:4.10.1-1.mga3
+ Revision: 302329
- new release
- rediff patch 3000
- requires xz instead of lzma

* Tue Aug 28 2012 tv <tv> 1:4.10.0-11.mga3
+ Revision: 284979
- rebuild for new binutils

* Sat Aug 04 2012 tv <tv> 1:4.10.0-10.mga3
+ Revision: 278429
- rebuild with compressed debug info
- re-enable testsuite

* Thu Aug 02 2012 tv <tv> 1:4.10.0-9.mga3
+ Revision: 277894
- rebuild with mini debug info

* Tue Jul 31 2012 tv <tv> 1:4.10.0-8.mga3
+ Revision: 276795
- patch 4000: merge find-debuginfo.sh changes from rpm-mageia-setup
- temporary disable test suite as the full build takes 5mn locally & on 32bits
  BS but 2 hours on jonud 64bit

* Tue Jul 31 2012 tv <tv> 1:4.10.0-7.mga3
+ Revision: 276745
- add "compressed" debug packages support

* Mon Jul 30 2012 tv <tv> 1:4.10.0-6.mga3
+ Revision: 276213
- add minidebug support
- build with db-5.3

* Fri Jul 20 2012 colin <colin> 1:4.10.0-5.mga3
+ Revision: 272737
- Add Fedora patch to add a new filesystem check for the usrmove

* Mon Jul 09 2012 dmorgan <dmorgan> 1:4.10.0-4.mga3
+ Revision: 268937
- Update rubygem patch ( from mandriva )

* Wed Jul 04 2012 rtp <rtp> 1:4.10.0-3.mga3
+ Revision: 267694
- fix testsuite
- fix filelist

* Thu Jun 28 2012 tv <tv> 1:4.10.0-2.mga3
+ Revision: 264615
- patch 133: fix segfaulting in "rpm -q --suggests foobar"

* Tue Jun 26 2012 tv <tv> 1:4.10.0-1.mga3
+ Revision: 264064
- fix & reenable testsuite

* Wed Jun 20 2012 tv <tv> 1:4.10.0-0.8.mga3
+ Revision: 262322
- drop patches:
  o 137, as there's no guaranty on the actual current encoding, we may
    return garbage and anyway mga has no l10n specs
  o 152: nss is now set at configure time
  o 1009 (rpm5 tags) as rpm-4.9+ doesn't choke on them
  o 2005, obsolete as rpm-4.8+ set LANG in %%___build_pre
- patch 2100: fix running testsuite when not having the uncompiled "magic" file
- rpmsign is only in rpmsign, not in main package too

* Tue Jun 12 2012 fwang <fwang> 1:4.10.0-0.3.mga3
+ Revision: 260027
- add conflicts on jpackage to ease upgarde

* Fri Jun 08 2012 tv <tv> 1:4.10.0-0.2.mga3
+ Revision: 257999
- fix filelist on ia32
- temporary disable testsuite due to an issue with the 'file' command
- bump conflicts with perl-URPM
- switch from db4.8 to db5.2
- patch 83: fix regression on doc conflict check; also reduces check overhead a little bit
- BR lua5.1-devel instead of lua-devel
- rediff patches 3002-4 (MIPS & ARM)
- annotate some patches
- drop (very) old post script for convertrpmr.sh
- rediff patches 3002-4 (MIPS & ARM)
- rediff patches 83 111 159 1009 2006
- patch 49 was merged upstream
- new release
- rediff weakdep patch
- drop merged FC patches
- drop merged patch 4000
- temporary disable patches 49, 83, 111, 145, 159, 1009, 2006

* Thu Apr 19 2012 dmorgan <dmorgan> 1:4.9.1.3-2.mga2
+ Revision: 231844
- Add upstream patch Warn but dont fail the build on STABS debuginfo (RhBug:725378, others)

* Thu Apr 05 2012 tv <tv> 1:4.9.1.3-1.mga2
+ Revision: 228572
- new release (pure security fixes)

* Tue Mar 13 2012 tv <tv> 1:4.9.1.2-22.mga2
+ Revision: 223263
- BR fakechroot, thus fixing all remaining testsuite issues (but a rpmspec
  faillure due to /etc/rpm/macros.d/20build.macros)

* Tue Mar 13 2012 tv <tv> 1:4.9.1.2-21.mga2
+ Revision: 223206
- merge patches 4103-4108 from FC:
  o fix memory corruption on rpmdb size estimation (#766260)
    (might help mga#4918):
  o fix couple of memleaks in python bindings (RH#782147)
  o fix regression in verify output formatting (RH#797964)
  o dont process spec include in false branch of if (RH#782970)
  o?\194?\160only warn on missing excluded files on build (RH#745629)
  o dont free up file info sets on test transactions
- patches 133, 1009: fix a testsuite regression

* Sat Mar 03 2012 tmb <tmb> 1:4.9.1.2-20.mga2
+ Revision: 217265
- restore P4000 as it's not causing the the out of memory errors

* Fri Mar 02 2012 dmorgan <dmorgan> 1:4.9.1.2-19.mga2
+ Revision: 216922
- Comment P4000, just to see if the regression saw is because of this

* Tue Feb 28 2012 tv <tv> 1:4.9.1.2-18.mga2
+ Revision: 215854
- simplify patch 70
- revert changes to patch 133, instead include missing extcond patch 134 (SuSE, mga#4012)

  + fwang <fwang>
    - use configure2_5x

* Mon Feb 27 2012 tv <tv> 1:4.9.1.2-17.mga2
+ Revision: 215717
- fix rpm -q --suggests (mga#4012)
- patch 5000: switch back to former, much smaller BDB memory pool size (RhBug:752897)

* Tue Feb 07 2012 tv <tv> 1:4.9.1.2-16.mga2
+ Revision: 206214
- run testsuite

* Thu Jan 12 2012 tv <tv> 1:4.9.1.2-15.mga2
+ Revision: 195417
- patch 3004: unconditionally disable libio usage (mga#1962)

  + dmorgan <dmorgan>
    - Fix ARM support ( rtp)
    - Add back P3004: Fix ARM support

* Sat Dec 24 2011 dmorgan <dmorgan> 1:4.9.1.2-14.mga2
+ Revision: 187127
- Fix perms of script.req and elfdeps

* Fri Dec 23 2011 anssi <anssi> 1:4.9.1.2-13.mga2
+ Revision: 186888
- fix filetriggers that were broken by incomplete rediff of the patch for
  rpm 4.9 (filetriggers.patch)

  + dmorgan <dmorgan>
    - Remove P5000, not usefull for us now

* Wed Dec 21 2011 dmorgan <dmorgan> 1:4.9.1.2-12.mga2
+ Revision: 185220
- Add %%epoch in Requires ( tks to boklm)

* Wed Dec 21 2011 dmorgan <dmorgan> 1:4.9.1.2-11.mga2
+ Revision: 185191
- Fix requires of the devel package

* Wed Dec 21 2011 blino <blino> 1:4.9.1.2-10.mga2
+ Revision: 185127
- fix perms of fileattrs directory (seems to break pkgconfig auto provides/requires)

* Tue Dec 20 2011 dmorgan <dmorgan> 1:4.9.1.2-9.mga2
+ Revision: 185086
- Rebuild in the BS
- Update to rpm 4.9.1.2 ( from work done on branch)
- Remove old sources

* Mon Nov 21 2011 dmorgan <dmorgan> 1:4.8.1-15.mga2
+ Revision: 170213
- Remove .la files

* Wed Nov 16 2011 jquelin <jquelin> 1:4.8.1-14.mga2
+ Revision: 168128
- another perl module required - this time for module::install powered dists

* Tue Nov 15 2011 jquelin <jquelin> 1:4.8.1-13.mga2
+ Revision: 167931
- perl(eumm) needs a recent CPAN::Meta to generate MYMETA files

* Mon Nov 14 2011 jquelin <jquelin> 1:4.8.1-12.mga2
+ Revision: 167751
- require a recent EUMM for perl in order to generate MYMETA files

* Sun Jun 19 2011 dmorgan <dmorgan> 1:4.8.1-11.mga2
+ Revision: 110107
- Add  File capability support

* Mon May 16 2011 dmorgan <dmorgan> 1:4.8.1-10.mga1
+ Revision: 99198
- Fix P147 to check for mageia too ( spotted by tvignaud )

* Sun Mar 27 2011 dmorgan <dmorgan> 1:4.8.1-9.mga1
+ Revision: 78198
- Fix previous commit
- Backport mdv commit 535522
  	- fix file trigger hang when several filetrigger scripts are run in parallel (mdvbz #57878)

* Fri Mar 18 2011 dmorgan <dmorgan> 1:4.8.1-8.mga1
+ Revision: 74203
- Add patch from rtp to fix build on arm (P3005)

* Fri Mar 04 2011 dmorgan <dmorgan> 1:4.8.1-7.mga1
+ Revision: 64225
- Really fix filetriggers

* Fri Mar 04 2011 dmorgan <dmorgan> 1:4.8.1-5.mga1
+ Revision: 64206
- Use texlive instead of tetex
- Fix file triggers

* Wed Mar 02 2011 dmorgan <dmorgan> 1:4.8.1-4.mga1
+ Revision: 62722
- Add a comment about patch64
- Add a comment about patch31 sent upstream
- As patch17 have been previously dropped, remove it from the spec file
- Change syslog patch and use the one sent upstream

* Tue Mar 01 2011 dmorgan <dmorgan> 1:4.8.1-3.mga1
+ Revision: 62080
- Drop old patch17
  Signed-off-by: cfergeau
  Signed-off-by: tvignaud

* Tue Mar 01 2011 dmorgan <dmorgan> 1:4.8.1-2.mga1
+ Revision: 62040
- Readd rpm-4.8.1-setup-rubygems.patch ( candidate for upstream )

* Thu Feb 24 2011 dmorgan <dmorgan> 1:4.8.1-1.mga1
+ Revision: 59113
- Add comment about patch17 that is a candidate for a drop
- Add exit to not build rpm for now
- Fix spec file ( from tv work)
- Comment release to be sure we do not upload rpm w/o a working perl-RPM4
- Remove patch 1017, to not diverge from main rpm.org regarding version comparison
- Restore rpm.org behaviour for %%exclude
- Update to rpm 4.8.1
- Fix typo
- Update to rpm 4.8 ( from cfergeau work )

  + tmb <tmb>
    - read rpmrc and rpmpopt from /usr/lib/rpm/mageia/

  + blino <blino>
    - add back manbo-rpmrc patch in SOURCES (thanks rtp)
    - use _real_vendor macro
    - revert manbo drop, it breaks many things (and builds packages as i386 on i586), we need to merge manbo files instead of dropping them

* Wed Jan 19 2011 tmb <tmb> 1:4.6.1-9.mga1
+ Revision: 24931
- hardcode mageia as distro name for now in order to force dropping requirements on rpm-manbo-setup-*
- drop P64, as it's manbo specific

* Mon Jan 17 2011 blino <blino> 1:4.6.1-8.mga1
+ Revision: 20921
- rebuild with new python

* Sun Jan 09 2011 blino <blino> 1:4.6.1-7.mga1
+ Revision: 3665
- rebuild with rpm-mageia-setup

* Sun Jan 09 2011 blino <blino> 1:4.6.1-6.mga1
+ Revision: 3615
- put the lowercase distro name in a macro (mandriva for now, as long as
  rpm-mageia-setup is not available, which needs an updated rpm)
- rebuild with rpm-mandriva-setup for now
- update rpmbuild unpackaged files check for mga

  + tmb <tmb>
    - drop rpm tags
    - rename mandriva to mageia
    - remove support for old mandriva versions
    - remove vendor checks (was only needed for Manbo labs)
    - imported package rpm


* Sat Jan  8 2011 Thomas Backlund <tmb@mageia.org> 1:4.6.1-6.mga1
- initial import
- switch from manbo_mkrel to mkrel

* Sat Nov 27 2010 Funda Wang <fwang@mandriva.org> 1:4.6.1-5mnb2
+ Revision: 601652
- rebuild for liblzma 5

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 1:4.6.1-4mnb2
+ Revision: 589999
- rebuild for python 2.7

* Mon Oct 18 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:4.6.1-3mnb2
+ Revision: 586616
- automatically handle ruby gem extraction in %%setup

* Thu Oct 07 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:4.6.1-2mnb2
+ Revision: 583901
- fix regression introduced with %%exclude change in previous release (fixes #61207)

* Wed Sep 29 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:4.6.1-1mnb2
+ Revision: 582007
- add '~' suffix to backup files created when using %%apply_patches
- finally put copyright & serial tags to death for real
- reapply fix for rmpvercmp with missing values & conflicts behaviour fix(#55810)
- update to to more recent debugedit that handles '.debug_pubtypes' section
- "New" release: 4.6.1 (while awaiting decission on where to go next...)
- fix %%exclude's behaviour to *only* mean exclude from %%files, not from check
  of unpackaged files. This brings back the behaviour we had in the past with
  rpm 4.4.8, and will require files not to be packaged to be deleted in %%install,
  and breaks building of any packages which incorrectly uses %%exclude for this
  purpose. Please fix any packages doing so! (P1016)

* Fri Aug 20 2010 Christophe Fergeau <cfergeau@mandriva.com> 1:4.6.0-15mnb2
+ Revision: 571456
- drop Pascal's patch for now
- fix "canonicalization unexpectedly shrank by one character" errors, patch by Anssi
- drop patch 135 which looks dubious
- revert previous commit, we don't want to diverge too much from rpm 4.x, we can
  readd it *after* this patch is upstreamed in rpm 4.x

  + Pascal Terjan <pterjan@mandriva.org>
    - Refuse to build a rpm with 2 identical triggers (#60699)

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - reapply fix for #55i810 (if not fully comprehended, those of us who wrote it
      does, ao removing out of ignorance and lack of insight will not e tolerated.

* Mon May 17 2010 Christophe Fergeau <cfergeau@mandriva.com> 1:4.6.0-14mnb2
+ Revision: 544968
- use db 4.8
- fix default perms in debug packages, #59083

  + Pascal Terjan <pterjan@mandriva.org>
    - Check chroot return code before running external script
    - Check chroot return code before running lua script

* Fri Apr 16 2010 Christophe Fergeau <cfergeau@mandriva.com> 1:4.6.0-12mnb2
+ Revision: 535522
- fix file trigger hang when several filetrigger scripts are run in parallel (#57878)

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuilt against nss-3.12.6

* Wed Feb 17 2010 Christophe Fergeau <cfergeau@mandriva.com> 1:4.6.0-10mnb2
+ Revision: 507168
- don't diverge from upstream wrt EVR comparisons

* Tue Feb 16 2010 Funda Wang <fwang@mandriva.org> 1:4.6.0-9mnb2
+ Revision: 506733
- rebuild for libpopt file path change

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - fix broken bitwise operator usage (thx to anssi for noticing)
    - do a new fix for #55810 that doesn't cause same regressions as the previously
      revert fix and hopefully no other regressions either.. ;)
      (P1010, http://rpm5.org/community/rpm-devel/4011.html)

* Fri Nov 20 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:4.6.0-8mnb2
+ Revision: 467682
- revert previous change as it'll break == dependencies on version only
  (which even requires-on-release policy requires) :/

* Fri Nov 20 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:4.6.0-7mnb2
+ Revision: 467652
- don't skip release comparision when checking conflicts if release value is
  missing (P1011 from Jeff Johnson, fixes #55810)

  + Michael Scherer <misc@mandriva.org>
    - fix unowned directory, reported by bitshuffler on irc, causing problem
      when installing rpm and using the wrong umask

* Fri Sep 25 2009 Olivier Blin <oblin@mandriva.com> 1:4.6.0-6mnb2
+ Revision: 448653
- remove n32 support for now (not actually used)
- handle n32 ABI in find-requires and find-provides (from Arnaud Patard)
- switch to armv5tl (from Arnaud Patard)
  There are little chances that we'll have armv4tl. Doesn't use
  armv5tel as some SoC have broken instructions in the "e" extension
- fix %%_isa rpm macros for ARM (from Arnaud Patard)
- mips build fixes: define __isa* macros otherwise rpm doesn't work
  (from Arnaud Patard)
- fix stack-protector check: -fstack-protector doesn't error if it's
  not supported but issues a warning, building test case with -Werror
  the test case fixes the issue (from Arnaud Patard)
- add %%mips macro define all mips abi (from Arnaud Patard)

* Sun Aug 23 2009 Anssi Hannula <anssi@mandriva.org> 1:4.6.0-5mnb2
+ Revision: 419760
- fix ignored Requires(pre) and (post) when they have a plain Requires
  counterpart (rpm-fix-corequisites.patch backported from upstream 4.7.1)
- fix legacy prereq detection (rpm-fix-islegacyprereq.patch backported
  from upstream 4.7.1)
- map prereq to Requires(pre,preun) instead of nothingness when building
  (rpm-map-prereq.patch backported from upstream 4.7.1)

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - Avoid adding Lua sources/patches twice when recursing (P1010, git backport)

* Fri Jul 24 2009 Anssi Hannula <anssi@mandriva.org> 1:4.6.0-4mnb2
+ Revision: 399298
- fix filetriggers to be called on package removal as well (regression
  introduced in 4.6.0 package because of an error in rediffing of
  filetriggers.patch; fixes bug #52333)

* Tue Jun 30 2009 Thierry Vignaud <tv@mandriva.org> 1:4.6.0-3mnb2
+ Revision: 391017
- bump release so that cooker's rpm is newer than 2009.1's one

* Thu Jun 11 2009 Christophe Fergeau <cfergeau@mandriva.com> 1:4.6.0-2mnb2
+ Revision: 385093
- add missing calls to rpmluaPop to patch 159, might fix #50579
- Revert switch to db4.7

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - Expose packagecolor tag and add new tags from rpm5 as rpm otherwise will break
      when these unknown tags might be found in the rpmdb. Notice that this will only
      make rpm recognize these, not implement actual support for them.. (P1008)
    - build against bdb 4.7
    - build against db4.7 rather than db4.6 from now on

  + Arnaud Patard <apatard@mandriva.com>
    - define apply_patches if not already done. This fix bootstrapping issues
      (eg building current rpm on older rpm or building rpm on a system without
      rpm)
    - fix dependency on patch as rpm-build is now using "patch -U" which has
      been introduced in version 2.5.9-7mdv2009.1.

* Fri Feb 13 2009 Christophe Fergeau <cfergeau@mandriva.com> 1:4.6.0-1mnb2
+ Revision: 340115
- Update to rpm 4.6.0

* Thu Jan 29 2009 Pixel <pixel@mandriva.com> 1:4.6.0-0.rc3.7mnb2
+ Revision: 335221
- add %%apply_patches: it can be used to replace all "%%patchN" lines,
  but it forces all patches to be "-p1".
- call %%_patch and %%_after_setup for use in rpm-mandriva-setup-build
  (useful for "--with git_repository")

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - don't wipe out $DOCDIR when using %%doc as it will wipe out any files that would
      happen to be installed during %%install. (P1008)

* Tue Jan 20 2009 Pixel <pixel@mandriva.com> 1:4.6.0-0.rc3.6mnb2
+ Revision: 331759
- replace nss-inithack patch with upstream patch
  (which is more complete, esp fixes rpmresign in perl-RPM4)
- add patch fixing rpmdsMerge on rpmdsSingle (fixes 07dep.t in perl-RPM4)
- fix segfault triggered by perl-RPM4 tests

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - fix internal enum value for xz (noticed by jnovy, thx!)
    - oops, fix a minor glitch with a final api change
    - add versioned requires on liblzma-devel since we *really* need latest api
      changes :)
    - update lzma payload support to add support for new xz format in parallel(P1007)

* Wed Dec 24 2008 Funda Wang <fwang@mandriva.org> 1:4.6.0-0.rc3.5mnb2
+ Revision: 318370
- temporarily disable graphviz BR

  + Michael Scherer <misc@mandriva.org>
    - rebuild for new python

  + Pixel <pixel@mandriva.com>
    - add conflict on urpmi-recover since rpm 4.6.0 dropped support for --repackage

* Thu Dec 18 2008 Pixel <pixel@mandriva.com> 1:4.6.0-0.rc3.3mnb2
+ Revision: 315608
- add patch153: "fix" segfault in mdkapplet (#46323)
- add patch154: fix compilation with Werror=format-security
- merge patch91 (check-dupl-files) into patch111 (check-files fix for "//" in buildroot)

* Mon Dec 15 2008 Pixel <pixel@mandriva.com> 1:4.6.0-0.rc3.2mnb2
+ Revision: 314562
- enable sqlite (was disabled after rpm-4.6.0 switch)

* Fri Dec 12 2008 Pixel <pixel@mandriva.com> 1:4.6.0-0.rc3.1mnb2
+ Revision: 313584
- 4.6.0-rc3
- drop patch153 (buildroot-subpackage), fixed upstream

* Thu Dec 11 2008 Pixel <pixel@mandriva.com> 1:4.6.0-0.rc2.2mnb2
+ Revision: 312890
- rediff patch71, patch83, patch91, patch140, patch145, patch147, patch1005
- fix patch2002 (python-writeHdlist), was broken with rpm 4.6 API

* Tue Dec 09 2008 Pixel <pixel@mandriva.com> 1:4.6.0-0.rc2.1mnb2
+ Revision: 312303
- use %%configure (so that libdir is correctly on x86_64)
- 4.6.0-rc2
- add patch152: fix build
- add patch153: buildroot with subpackages issue
- drop already unused %%buildnptl (obsolete since rpm uses system libdb)
- drop patch134 (defaultbuildroot), so %%defaultbuildroot is no more used,
  global %%buildroot is used, and BuildRoot is no more handled
- drop patch56 (ppc32). hopefully now unneeded
- drop patch44 (amd64-x86_64 compat). hopefully now unneeded
- drop patch112 (dont-use-rpmio-to-read-file-for-script), only needed on rpm 4.4.8?
- drop patch1002 (default-topdir--usr-src-rpm). it is now /root/rpmbuild
- drop patch1003: drop support for "suggests" the way rpm >= 4.4.7 do it
  (all Mandriva packages uses the new "suggests" nowadays)
- drop patch139 (do-not-allow-fileconflict-between-non-colored-file),
  since partially applied upstream (47c85270631de173d873b98bc79727e2db203007)
- drop popt (it is no more internal), drop patch1004, patch2004
- drop patch3 ("file" is no more internal)
- drop patch149 (upstream has already got rid of internal db)
- drop patch1450 (problem fixed upstream, though differently)
- drop patch132 (extcond), patch133 has been simplified (butchered) to work without it
- drop patch1133 (integrated in patch133 (weakdeps))
- drop patch100 (rpmbuild-missing), no more needed since we have rpmb_deprecated
- drop patch142, patch143, patch144, patch150 applied upstream
- simplify patch1001 since most is upstream, create patch1006 containing the
  PayloadIsLzma compat issue
- adapt patch137 (headerIconv)
- adapt patch31 (syslog)
- adapt/simplify patch114: only specifically read macros.d/*.macros
- adapt patch2000, patch2001 (serial/copyright tag)
- adapt patch133 (weakdeps), drop --suggests/--recommends difference
- rediff patch49, patch64, patch70, patch141, patch146, patch147, patch148,
  patch151, patch2002, patch2005

* Sun Oct 19 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:4.4.2.3-22mnb2
+ Revision: 295367
- rebuild against liblzma which I had to bump the major of yet again
- actually remember to bump popt release as well this time (popt should REALLY
  be split out!!!)

* Sat Oct 18 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:4.4.2.3-21mnb2
+ Revision: 294824
- fix build with new liblzma (updates P1001)

  + Pixel <pixel@mandriva.com>
    - failing triggers must not block an update (otherwise both packages are kept)

* Wed Oct 01 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-20mnb2
+ Revision: 290443
- protect-against-non-robust-futex patch: remove the ugly error messages
  when non-root

* Wed Oct 01 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-19mnb2
+ Revision: 290325
- ensure stale futex locks do not block (#41868)

* Thu Sep 11 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-18mnb2
+ Revision: 283690
- fix broken cpio for hardlink on softlink (#43737)
- remove /usr/lib/libpopt.so.0 symlink (unneeded)

* Sat Sep 06 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-17mnb2
+ Revision: 281842
- use external libdb-4.6.so instead of internal one (was DB 4.3.27: December 22, 2004).
  (hopefully fixing #41868)

* Tue Aug 26 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-16mnb2
+ Revision: 276212
- add patch148 which ensures chroot errors are not ignored
  (the bug occured on mandriva build system, the files
  were installed on the non rooted system)

* Tue Aug 05 2008 Frederic Crozat <fcrozat@mandriva.com> 1:4.4.2.3-15mnb2
+ Revision: 263799
- bump popt release too
- Bump minimal version of rpm-mandriva-setup, to ensure filetriggers
  are enabled during upgrade from older distributions

* Thu Jul 17 2008 Oden Eriksson <oeriksson@mandriva.com> 1:4.4.2.3-14mnb2
+ Revision: 237798
- bump release for popt as well
- fix deps and rebuild against latest neon-devel

* Fri Jul 04 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-13mnb2
+ Revision: 231680
- fix memory leak in patch124 (regression introduced on 2008-06-23)
- fix detecting wether filetriggers are activated (through %%_filetriggers_dir)

* Thu Jun 26 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-12mnb2
+ Revision: 229317
- fix --testing errors introduced by filetriggers

* Tue Jun 24 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-11mnb2
+ Revision: 228550
- nicely handle /etc/rpm/macros.cdb disappearance (esp. for people having %%_dbapi set there)

* Mon Jun 23 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-10mnb2
+ Revision: 228082
- enhance patch124 to use "Dirnames" db before using "Packages" db
  (hence much less db accesses in the pathological "COPYING" case)
- rpm must feature PayloadIsLzma = 4.4.2-1 to be the most compatible (?!)
  (with SuSE, and with temporary cooker packages with PayloadIsLzma <= 4.4.2.2-1)

* Sun Jun 22 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-8mnb2
+ Revision: 227894
- PayloadIsLzma version must be at least 4.4.6-1 to be compatible with mdv2008.0
- fix segfault when transaction fails

* Fri Jun 20 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-7mnb2
+ Revision: 227396
- drop our old macros.cdb, which was forcing old values,
  esp "verify" which forcing rpm to verify db after each changes
  (which was making rpm quite slow when rpmdb was not in cache)
- cleanup: drop not applied global-RPMLOCK patch

* Thu Jun 19 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-6mnb2
+ Revision: 226213
- fix filetriggers (librpm was exiting in case of sigpipe in filetrigger script)
- checks on "non packaged binary packages" now depend on %%_missing_subpackage_terminate_build (patch147)
- checks on "non packaged binary packages" only done on "mdv" packages (patch147)

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - fix version typo
    - switch to use liblzma for lzma payload (P1000, partly derived from rpm5.org & OpenSuSE)

* Wed Jun 11 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-4mnb2
+ Revision: 218093
- rpmbuild: add patch to ensure some parse errors are really fatal as they should

* Mon Jun 09 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-3mnb2
+ Revision: 217217
- add new fatal errors (during package build):
  o disallow scriptlets for non packaged binary packages
  o "%%files foo" for subpackages is now mandatory
- do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
- replace "%%post -p ldconfig" hack with a full featured generic solution:
  filetriggers (cf http://wiki.mandriva.com/en/Rpm_filetriggers)
- "#%%define foo bar" is now a fatal error
- handle "%%posttrans -p ..." with no script body (eg: %%posttrans -p /sbin/ldconfig)
- add "requires tar" in rpm-build
- fix build of debugedit (patch143)

* Tue May 13 2008 Thierry Vignaud <tv@mandriva.org> 1:4.4.2.3-1mnb2
+ Revision: 206778
- fix build on x86_64

  + Pixel <pixel@mandriva.com>
    - 4.4.2.3
    - add patch142 which ensures chroot errors are not ignored
      (the bug occured on mandriva build system, the files from package binutils
      were installed on the non rooted system)
    - drop patches applied upstream: 136, 138
    - rediff patch17

* Tue Apr 01 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-0.rc1.7mnb1
+ Revision: 191469
- postpone and group ldconfig %%post in %%posttrans instead of wrongly skipping ldconfig

* Fri Mar 28 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-0.rc1.6mnb1
+ Revision: 190842
- rebuild with fixed libneon0.26-devel

* Mon Mar 17 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-0.rc1.5mnb1
+ Revision: 188330
- add support for "suggests" and "enhances" in rpmds (needed for "sophie") (nanardon)
- use %%_vendor instead of %%vendor (thanks-to/required-by nanardon)
- fix typo in recent commit
- fix broken symlink (due to %%rpmversion != %%srcver for rc1)
- trivial fix for Russian translation (#38713)

  + Toshihiro Yamagishi <toshihiro@turbolinux.co.jp>
    - get rid of _host_vendor definition. It should be defined by rpm-xxx-macros.
    - use original find-requires,find-provides,find-lang when build with turbolinux.

* Sat Mar 01 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-0.rc1.3mnb1
+ Revision: 177474
- fix file conflicts wrongly allowed on x86_64
- when dropping requires during tsort, do not display "PreReq" when it really is "Requires"
- rpm-mandriva-setup and rpm-mandriva-setup-build requires are only on Mandriva
- add buildlang patch which unsets locales when building packages (for Turbolinux)

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%mkrel with %%manbo_mkrel for Manbo Core 1

* Thu Feb 14 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-0.rc1.2mdv2008.1
+ Revision: 167788
- use rpmrc and rpmpopt from rpm-manbo-setup
- get best lang from rpm HEADERI18NTABLE, instead of getting first fuzzy match
  (eg: zh_TW matches zh_CN whereas zh_TW entry is available)
- debugedit: remove a wrong check in case %%_topdir is /RPM (from Turbolinux)
- add japanese popt translations
- add Turbolinux specific patches:
  o re-allow "Serial" and "Copyright" (aliases of "Epoch" and "License")
    (to ease Turbolinux migration)
  o add writeHeaderListTofile function into python binding
    (needed by Turbolinux buildman build system)

  + Toshihiro Yamagishi <toshihiro@turbolinux.co.jp>
    - headerIconv.patch: check realloc() value
    - convert the data to a specific encoding which used in the selected locale.

* Mon Jan 28 2008 Pixel <pixel@mandriva.com> 1:4.4.2.3-0.rc1.1mdv2008.1
+ Revision: 159090
- 4.4.2.3 adds ix86 macros files to x86_64
- new release 4.4.2.3-rc1
- libpopt needs a release number different from rpm so that we can reset rpm's
  release and increase libpopt's
- drop applied patches: patch82 (ordering), patch98 (bad pointer),
  patch108 (dgettext), patch116 (qv), patch119 (without-O2),
  patch121 (timeout 60secs), patch127 (rpmbuild --quiet),
  patch128 (rpm -K segfault), patch136 (macro on last line),
  patch1006 (triggerprein), patch1007 (russian),
  patch1008 (display Requires found),
- drop patch135 (truncated rpmProblemString): no more needed, workarounded
  upstream

* Wed Jan 23 2008 Pixel <pixel@mandriva.com> 1:4.4.2.2-7mdv2008.1
+ Revision: 157054
- fix rpmbuild not printing Requires after build (fix backported from 4.4.8) (#36672)
- allow doc conflict in same transaction (#37040)
  (it was already allowed in different transactions)
- fix russian translation (#36974)

* Sat Jan 12 2008 Anssi Hannula <anssi@mandriva.org> 1:4.4.2.2-6mdv2008.1
+ Revision: 149522
- allow conflicting ghost file types as sometimes the same ghost file
  is a file in one package and a symlink in another package (modifies
  rpm-4.4.2.2-allow-conflicting-ghost-files.patch)

* Tue Jan 08 2008 Pixel <pixel@mandriva.com> 1:4.4.2.2-5mdv2008.1
+ Revision: 146377
- %%triggerprein were missing in 4.4.2.2, adding them

* Thu Dec 20 2007 Pixel <pixel@mandriva.com> 1:4.4.2.2-4mdv2008.1
+ Revision: 135996
- fix multiline macro handling on last line of spec file (#27417)
- fix truncated "file conflict" error message in russian (#31680)

* Tue Dec 18 2007 Pixel <pixel@mandriva.com> 1:4.4.2.2-3mdv2008.1
+ Revision: 132430
- re-introduce temporarily BuildRoot so that rpm builds
- drop patch for SOURCEPACKAGE (unneeded in rpm 4.4.2.2 which keeps compatibility)
- fix defaultbuildroot patch (fix building with %%defaultbuildroot and subpackages)
- allow conflicting %%ghost files (as used to be in rpm >= 4.4.6)
- modify patch no-doc-conflicts instead of patching it
- for compatibility with rpm 4.4.8, allow conflicting doc files in
  /usr/share/man, /usr/share/gtk-doc/html /usr/share/gnome/html

* Mon Dec 17 2007 Pixel <pixel@mandriva.com> 1:4.4.2.2-2mdv2008.1
+ Revision: 125038
- patch134 introduces %%defaultbuildroot to use instead of %%buildroot in our global macros
- keep libpopt.so versioning from 4.4.8 (to avoid warnings)
- fix URL
- switch to 4.4.2.2 (using epoch: 1)
- add patch132 and patch133 to handle "Suggests" via RPMTAG_SUGGESTSNAME
- add patches to be compatible with >= 4.4.8 :
  o patch1000: handle %%buildroot macro
  o patch1001: handle suggests via RPMTAG_REQUIRENAME + RPMSENSE_MISSINGOK
  o patch1001: lzma-support (integrates patch130 (lzma-fixes), patch131 (lzma_alone))
  o patch1002: default %%_topdir is /usr/src/rpm
  o patch1003: handle RPMSENSE_MISSINGOK (integrates patch129 (do-not-cache-unsatisfied-suggest))
- drop unneeded patches:
  o applied: patch63 (applied in lib/package.c), patch68, patch72,
    patch77 (%%_srcdefattr), patch92 (newtar), patch94 (rpmv3-support),
    patch113 (%%_docdir_fmt), patch123 (find-lang omf)
  o patch1 (no builtin zlib)
  o patch2 (rpm is dynamically linked by default)
  o patch85 (no more perl module)
  o patch87 (was disabling dirname require introduced in 4.4.6)
  o patch89 (>= 4.4.6 specific compilation issue)
  o patch107 (fixed differently in changeset 6799:446988cfb9c1)
  o 4.4.8 specific: patch109, patch117 (dont-replace-config-not-in-db),
    patch118 (lowercase platform), patch120 (segfault fix), patch122 (fix
    crash with buggy rpm and FILELINKTOS), patch125 (popt.h fix), patch126
    (platform32 support)
  o 4.4.8 specific?: patch115 (dont-clean-buildroot-in-install)
- adapt patches:
  o rediff: patch31 (syslog), patch64 (vendor popt), patch84 (rpmqv-ghost),
    patch116 (qv-use-same-indentation), patch49, patch56, patch82, patch86,
    patch112, patch119
  o patch3 (prefer-pic in "file" lib .la)
  o patch17 (keep enhancements from upstream version)
  o patch114 (read our macros files)
  o patch124 (speedup-by-not-checking-same-files-with-different-paths-through-symlink)
    and add patch1124 (revert-unused-skipDir-functionality) needed by patch124
- use autoreconf and don't do it in db/dist (it fails)
- drop perl-RPM (unused and no more in rpm 4.4.2.2)
- drop now unneeded perldirs patch85
- don't build apidocs since we don't bundle them
- drop patch78 (Do not use futex, but fcntl) which is not doing anything anymore

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - use LZMA_Alone file format, even with newer versions (P131, from cvs)
    - be more consistent and use unlzma in stead of lzma -d -c in rpm2cpio.sh (lzma patch)
    - drop unused leftover macros for lzma patch..
    - final fix of lzma payload patch, it can now be used properly same way as gzip and bzip2
    - correctify lzma fix patch
    - switch to patch from cvs for lzma fixes
    - update arguments for lzma utils as current old arguments breaks it
    - I suck, don't move man pages around at all and stop messing:p
    - move man page for perl module to perl-RPM package

  + Olivier Blin <oblin@mandriva.com>
    - do not expand _install_langs macro in default /etc/rpm/macros
    - fix typo in default /etc/rpm/macros
    - explicitely require neon-devel 0.26 (does not build with neon 0.27)

* Tue Oct 02 2007 Pixel <pixel@mandriva.com> 4.4.8-22mdv2008.0
+ Revision: 94448
- fix rpm allowing to remove a package which is both suggested and required (#34342)

* Fri Sep 28 2007 Pixel <pixel@mandriva.com> 4.4.8-21mdv2008.0
+ Revision: 93603
- remove global RPMLOCK, it doesn't seem to fix rpmdb issues, and may cause
  installer to crash

* Thu Sep 27 2007 Pixel <pixel@mandriva.com> 4.4.8-20mdv2008.0
+ Revision: 93272
- patch global-RPMLOCK:
  o fix rebuilddb (#34181)
  o don't lock when querying the db as non-superuser
  o fix locking in shared mode (ie fix typo)
  o remove message "RPMLOCK_NOWAIT should have been set!"
    which can't be done reliably
  o more debug messages about RPMLOCK

* Wed Sep 26 2007 Pixel <pixel@mandriva.com> 4.4.8-19mdv2008.0
+ Revision: 93120
- patch global-RPMLOCK:
  o allow rpm to not wait on lock when RPMLOCK_NOWAIT is set
  o ensure we don't have a dead-lock in package scriptlets which call "rpm -q"
    (eg: dkms). but it will die with an error
  o do create /var/lib/rpm directory when needed (as done in rpmdb/db3.c)
  o use flock instead of fcntl+F_SETLK
    (so that we really ensure the same process doesn't open twice the db)
  (still need not to lock when accessing in shared mode with not enough rights
  to write RPMLOCK)
- fix creating /RPMLOCK instead of /var/lib/rpm/RPMLOCK

* Mon Sep 24 2007 Pixel <pixel@mandriva.com> 4.4.8-18mdv2008.0
+ Revision: 92580
- do not use __db* files anymore, make them private
- (re-)add a global lock to ensure everything is correct
  (to ensure doing "rpm -qa" is always correct even if an upgrade is in
  progress)
- fix rpm -K segfaulting on corrupted header (#33735)

* Mon Sep 10 2007 Pixel <pixel@mandriva.com> 4.4.8-17mdv2008.0
+ Revision: 84150
- make "rpm -bb --quiet" quiet as should be

* Thu Sep 06 2007 Pixel <pixel@mandriva.com> 4.4.8-16mdv2008.0
+ Revision: 81086
- bug fix release, fix stupid typo in /etc/platform32 reading patch

* Thu Sep 06 2007 Pixel <pixel@mandriva.com> 4.4.8-15mdv2008.0
+ Revision: 80965
- really allow to use "linux32 rpm -bb" instead of "linux32 rpm -bb --target x86_64"
  (it uses /etc/rpm/platform32)

* Wed Sep 05 2007 Pixel <pixel@mandriva.com> 4.4.8-13mdv2008.0
+ Revision: 79852
- allow to use "linux32 rpm -bb" instead of "linux32 rpm -bb --target x86_64"
  (for this to work, %%{_host_cpu32} must be set in rpm-mandriva-setup)

* Thu Aug 30 2007 Pixel <pixel@mandriva.com> 4.4.8-12mdv2008.0
+ Revision: 75298
- fix popt.h (remove N_) (#31397)

* Wed Aug 29 2007 Pixel <pixel@mandriva.com> 4.4.8-11mdv2008.0
+ Revision: 74355
- add patch to speedup simple "rpm -e" or "rpm -U"
- make find-lang --with-gnome picks up omf files (rhbz#251400) (rpm.org patch)
- add the bug number fixed

* Tue Aug 21 2007 Pixel <pixel@mandriva.com> 4.4.8-10mdv2008.0
+ Revision: 68566
- patch fixing parse_hdlist (and so genhdlist2) on heavy loaded boxes
- fix segfault on weird rpm that used to work (#32102)
- remove recursive %%_mandir (and don't keep it, it's not needed anymore)

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%{_datadir}/man by %%{_mandir}!
    - replace %%_datadir/man by %%_mandir!

* Sat Aug 18 2007 Oden Eriksson <oeriksson@mandriva.com> 4.4.8-9mdv2008.0
+ Revision: 65549
- don't provide these files twice:
 /usr/lib/rpm/rpmdb_deadlock
 /usr/lib/rpm/rpmdb_dump
 /usr/lib/rpm/rpmdb_load
 /usr/lib/rpm/rpmdb_loadcvt
 /usr/lib/rpm/rpmdb_stat
 /usr/lib/rpm/rpmdb_svc
 /usr/lib/rpm/rpmdb_verify
 they are now only provided in the main rpm package, and not
 also in the devel package. that is the way to go according to
 jbj.

  + Thierry Vignaud <tv@mandriva.org>
    - fix URL

* Mon Aug 06 2007 Pixel <pixel@mandriva.com> 4.4.8-8mdv2008.0
+ Revision: 59505
- do not use nptl on any arch (since x86_64 specific issues seem to disappear
  when using same locking mechanism as x86) (may fix #32102)
- fix segfault occuring with some old rpm v3 from urpmi test cases
- allow building --with debug
- restore do-check-free-size-when-bavail-is-0 patch (after rediff)

* Wed Jul 25 2007 Olivier Thauvin <nanardon@mandriva.org> 4.4.8-7mdv2008.0
+ Revision: 55450
- fix #31535: lowercase OS tag to compare against platform
- use upstream patch

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - add requires on lzma

* Fri Jul 06 2007 Olivier Thauvin <nanardon@mandriva.org> 4.4.8-6mdv2008.0
+ Revision: 48984
- fix config file replace when not yet in db
- kill not bad macros definition
- find-lang is now a perl script

* Fri Jun 22 2007 Anssi Hannula <anssi@mandriva.org> 4.4.8-5mdv2008.0
+ Revision: 42672
- require arch-specific libpopt and libpopt-devel
- add back dropped librpm-devel and libpopt-devel provides

* Wed Jun 20 2007 Olivier Thauvin <nanardon@mandriva.org> 4.4.8-4mdv2008.0
+ Revision: 41943
- fix buildreq for autoconf/automake
- apply new devel policy

* Tue Jun 19 2007 Olivier Thauvin <nanardon@mandriva.org> 4.4.8-3mdv2008.0
+ Revision: 41414
- kill coloring patch, buggy, and not so usefull
- patch116: fix rpm -V output (#31287)

* Sun Jun 10 2007 Olivier Thauvin <nanardon@mandriva.org> 4.4.8-2mdv2008.0
+ Revision: 37847
- patch115: avoid breakage of conectiva --without bm feature
- remove patch 110, add patch114: do no longer use rpmrc, using only macros instead, so requiring latest rpm-mandriva-setup to have /etc/rpm/platform
- fix perl module release
- patch to backport _docdir_fmt macro
- 4.4.8
  o rediff patch 72, 87, 49, 62, 17, 56, 64
  o kill patch (merge or fix upstream, woot):
    57, 80, 90, 93, 193, 95, 96, 97, 99, 103, 104, 105, 109, 110, 111,
    112, 114, 115, 101, 102, 107
  o kill patch 69, hard to maintain, will be merge upstream
  o Patch109: workaround specfile parsing check,
    http://rpm5.org/cvs/tktview?tn=6
  o Patch110: still read rpmrc (this should die one day)
  o Patch111: trim twice / in buildroot, making unpackaged files check failing
  o Patch112: avoid a very issue regarding Fopen()

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - use %%{ix86} & %%{sunsparc} macros for x86 & sparc
    - use %%{sunsparc} macro to ensure sparcv9 gets included too

  + Pixel <pixel@mandriva.com>
    - make it explicit that older perl-URPM are not compatible with 4.4.8
    - add patches 112 113 114 115 from both rpm 4.4.9 and hg.rpm.org
    - cleanup provides-obsoleted.patch, moving other fixes into rebuilddb-with-root.patch
    - more complete fix-segfault-on-header-without-RPMTAG_NAME patch (from upstream)
    - don't segfault on header without RPMTAG_NAME
    - add requires pkgconfig in rpm-build (#30632)
      (it is needed for performing automatic computation of pkgconfig files
      dependencies, see /usr/lib/rpm/mandriva/pkgconfigdeps.sh)
    - add patch (ensure-uninst-callback-is-called-for-empty-packages)
      to allow urpmi to display "remove package foo" when removing an empty package

* Wed Apr 25 2007 Adam Williamson <awilliamson@mandriva.org> 4.4.6-22mdv2008.0
+ Revision: 18290
- rebuild against new beecrypt


* Wed Feb 14 2007 Pixel <pixel@mandriva.com> 4.4.6-21mdv2007.1
+ Revision: 120751
- fix parsing ")" (for if statements in spec files for example)
- rpm handles nicely failing %%pre, but it doesn't handle the rest
- patch to use dgettext instead of gettext to allow progs like urpmi to use
  their own textdomain and still have rpm translations
- fix checking available free space when "non-superuser free space" is 0

  + Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - requires newer rpm-mandriva-setup for rtld(GNU_HASH) notes

* Fri Jan 12 2007 Pixel <pixel@mandriva.com> 4.4.6-19mdv2007.1
+ Revision: 108072
- P98: security fix for CVE-2006-5466
-mv8 which is deprecated and no longer valid (Per Oyvind, #26501)

  + Thierry Vignaud <tvignaud@mandriva.com>
    - provides with unexpanded macros aren't that nice

* Mon Jan 08 2007 Pixel <pixel@mandriva.com> 4.4.6-18mdv2007.1
+ Revision: 105990
- fix bug 27987 where sslexplorer rpm has "Source RPM: (none)" and so rpm
  thought it is a src.rpm. the fix is only done for old v3 rpms
- "rpm -i --root" as user can't work, don't silently ignore the failing chroot()
- fix --root rpm option failing for non-root users (Christiaan Welvaart)
- really commit the patch
- fix segfault on weird buggy rpm header
- fix query format xml on rpm header with tag 265 which has no name (#27108)

* Fri Dec 08 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 4.4.6-12mdv2007.1
+ Revision: 93842
- generate PIC code for static objects that can be built into a DSO
- remove (obsolete) arch-dependent flags
- don't build statically linked executables
- Fix zlib tree to parallel build, propagate optflags to there too.
- Introduce new ppc32 arch, fix ppc64 bi-arch builds, fix ppc builds on newer CPUs.
- fix build on ppc64

  + Pixel <pixel@mandriva.com>
    - fix segfault on some old format rpms (#27263)

* Thu Nov 30 2006 Pixel <pixel@mandriva.com> 4.4.6-11mdv2007.1
+ Revision: 88894
- rebuild for python  2.5
- add patches fixing #26545:
  o don't leave behind /usr/X11R6/lib/X11/app-defaults;456ac510 on error
  o fix segfault
- ignore getcwd failing (db_abshome will not be set,
  it may affect db/log/log_archive.c, but that should be ok) (#20897)
- fix "rpm -bs t.spec" returning buggy error message
  "t.spec: No such file or directory" when rpm-build is not installed
- fix free on invalid pointer after displaying "Unable to open temp file" (#27260)
- have a nice error message when chroot fails
  (instead of the dreaded: "enterChroot: Assertion `xx == 0' failed.")

  + Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - Extend #27260 fix to its root cause as there are other instances of a
      similar bug in other sources (yet, unexposed/reported).

* Fri Sep 15 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.6-10mdv2007.0
+ Revision: 61429
- Bump release number
- Improve previous patch: make it conditional on the environment variable RPM_IGNORE_SCRIPTLETS_FAILURE
- Allow preinstall scriptlets to fail and not interrupting the installation.
  This is a workaround for bug 25598.

* Sat Aug 19 2006 Olivier Thauvin <nanardon@mandriva.org> 4.4.6-9mdv2007.0
+ Revision: 56766
- bump release
- revert to my own chroot patch, thee second one is broken

* Sun Aug 13 2006 Olivier Thauvin <nanardon@mandriva.org> 4.4.6-8mdv2007.0
+ Revision: 55706
- bump release
- buildrequires lua-devel
- import mailscanner
- update patch with C. Welvaart fixes

  + Rafael Garcia-Suarez <rgarciasuarez@mandriva.com>
    - Fix typos

* Sat Jul 29 2006 Olivier Thauvin <nanardon@mandriva.org> 4.4.6-7mdv2007.0
+ Revision: 42481
- bump release
- add upstream patch97: fix dbenv
- patch96: fix #23774

* Thu Jul 27 2006 Olivier Thauvin <nanardon@mandriva.org> 4.4.6-6mdv2007.0
+ Revision: 42186
- fix rpmv3 patch: rpm version in the lead in 3 for both rpm 3 and 4
- fix #23075: patch 95, use tee -a

* Wed Jul 26 2006 Olivier Thauvin <nanardon@mandriva.org> 4.4.6-5mdv2007.0
+ Revision: 42052
- patch93: support rpm v3
- bump release
- ensure leaveChroot can't be run by another function which is not the the caller of enterChroot
- remove changelog from spec
- add patch 93 (disable by default, need tests) to fix issue in rpmdb when mixing 'rpm --root' and 'chroot rpm'
- update macros in the spec
- provide some /etc/rpm files
- -3mdv release
- fix patch in patch
- better rpmdb.h c++ fix
- Patch90: fix unchecked end of line in macro expand
- patch 89: make rpmdb.h compliant
- file in /etc are %%config
- patch 88: readd SOURCEPACKAGE tag to source rpm
- make no_dirname_dep patch configurable with a macro
- bunzip patch, merge rpm 4.4.6
- initial import of rpm
- initial import of rpm

  + Rafael Garcia-Suarez <rgarciasuarez@mandriva.com>
    - 4.4.6-4mdk
    - Patch by Pixel to use --wildcards when using tar to list all specfiles in a tar
      ball (this fixes rpm -t).
    - Add patch 91: avoids taking into account duplicates in file list
      when checking for unpackaged files

* Wed Jul 12 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.6-4mdv2007.0
- Fix rpm -ta (Pixel)

* Thu Jun 22 2006 Olivier Thauvin <nanardon@mandriva.org> 4.4.6-3mdv2007.0
- patchs:
  - fix rpmdb.h c++ compilation (C. Welvaart)
  - fix unchecked end of string in macro expand (O. Thauvin)
  - fix check unpackaged files script (R. Garcia-Suarez)
- update macros provide by the spec used for bootstraping
- set some /etc/rpm/macros.* as config(noreplace)

* Mon Jun 12 2006 Olivier Thauvin <nanardon@mandriva.org> 4.4.6-2mdv2007.0
- Patch88: readd SOURCEPACKAGE tag into src.rpm

* Fri May 26 2006 Olivier Thauvin <nanardon@mandriva.org> 4.4.6-1mdv2007.0
- 4.4.6
- rediff patches
- add patch to disable dirnames dependencies for now

* Tue Mar 21 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.5-2mdk
- Require latest rpm-mandriva-setup

* Tue Mar 14 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.5-1mdk
- 4.4.5
- Remove patches 41 and 87, merged upstream
- Rediff patches 69 and 78
- Make rpm-build require libtool-base instead of libtool (bug #21162)
- Turn the triggerun in post scriptlet

* Tue Mar 07 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.4-4mdk
- Patch 87

* Tue Feb 07 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.4-3mdk
- Move popt(3) man page into libpopt-devel (bug 18161)
- Add coreutils in prerequisites (bug 19144)
- Fix dangling symlink (bug 6788)

* Tue Jan 17 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.4-2mdk
- Patch 86: don't cache Depends DB (Olivier Thauvin)
- Bump requires on rpm-mandriva-setup

* Thu Jan 05 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.4-1mdk
- New version 4.4.4
- Rediff patches 31, 49, 62, 69, 71, 78, 82, 84
- Remove patch 66 (fixed upstream)
- Remove patch 74 (no longer necessary, no legacy prereqs anymore)
- Remove patch 76 (should be unnecessary now that RH bug 151255 is fixed)
- Remove patch 79 (applied upstream)
- Remove patch 81 (does nothing)
- New subpackage perl-RPM, and patch 85 to install it in vendor dir
- Use static libneon, libsqlite3 and libopenssl
- Update condition for triggerun
- Add conditional BuildRequires on nptl-devel
- Disable popt tests
- Remove selinux
- Requires recent rpm-mandriva-setup for _rpmlock_path macro

* Sun Nov 13 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.2-6mdk
- rebuild for openssl (ask by Oden)

* Sun Oct 23 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.2-5mdk
- Fix #19392

* Fri Sep 16 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 4.4.2-4mdk
- buildrequires: rpm-mandriva-setup-build
- fix simple coloring patch, aka merge it correctly
- re-add the no-doc-conflicts patch for colored packages

* Tue Aug 30 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.2-3mdk
- patch 80: fix #17774
- patch 81, 82: should fix ordering issue
- BuildRequires: bzip2-devel (thanks Christian)

* Sat Aug 20 2005 Frederic Lepied <flepied@mandriva.com> 4.4.2-2mdk
- 79: fix deadlock from RedHat bug #146549.

* Fri Jul 22 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.2-1mdk
- 4.4.2
- remove patch:
    52: merged upstream
    67: fixed upstream
    73: merged upstream
    78: merged upstream
    79: merged upstream
    32, 33, 36: no more need hack
- rename rpm-python to python-rpm    
- use fnctl when not using futex
- use nptl only on few arches (ppc* x86_64 pentium3,4/Athlon)

* Thu Jun 23 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-10mdk
- add requires to rpm-build after the rpm-mandriva-setup split

* Tue Jun 21 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-9mdk
- Enable NPTL and co
- rework patch77: allow %%_srcdefattr as macro for src.rpm
- Patch78: reread few macro between build
- Patch79: fix rpm --eval '%%' overflow

* Fri Jun 17 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.1-8mdk
- Move dependencies on unzip, make and elfutils from rpm to rpm-build

* Sun Jun 05 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-7mdk
- patch77: allow to set root/root as owner of files in src.rpm
- rebuild with neon 0.24 as it moved in main instead 0.25

* Thu Jun 02 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.1-6mdk
- Patch 76 : allow to rebuild db with --root option

* Wed May 18 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-5mdk
- update french translation
- disable NPTL system + --with to enable it
- --w/o pyhton switch
- remove db_private patch as it breaks concurrent access

* Mon May 16 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-4mdk
- really apply patch (I sucks)
- some cleaning

* Mon May 16 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-3mdk
- Patch71: Ordering transaction on erasure
- Patch72: rpm -[Ui] check files conflicts
- Patch73,74: Fedora patch, fixing bug

* Fri May 13 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-2mdk
- patch70: allow rpm -bb --short-circuit
- conflicts man-pages-pl < 0.4-9mdk
- move spec mode for emacs into rpm-mandriva-setup
- buildrequires
- remove locales files from libpopt

* Wed May 11 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 4.4.1-1mdk
- Adapt part of the coloring patch (patch 62)
- Fix a few French translations (patch 69)
- Require libneon 0.25

* Mon May 09 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-0.7mdk
- BuildRequires readline-devel (P.O. Karlsen)
- --disable-{posixmutexes,pthreadsmutexes} on sparc (P.O. Karlsen)
- patch68: being able to read old rpms
- update source url
- fix file list for ppc (C. Welvaart)

* Fri May 06 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-0.6mdk
- use system sqlite
- force -fPIC on amd64 (for popt)
- perform test for popt
- patch67 fix build with gcc4

* Wed May 04 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-0.5mdk
- workaround make -j

* Wed May 04 2005 Olivier Thauvin <nanardon@mandriva.org> 4.4.1-0.4mdk
- 4.4.1
- remove biarch, use mklibname (see 4.2.3-10mdk)
- do no longer patch the config, use /usr/lib/rpm/VENDOR/rpmrc instead
- require rpm-mandriva-setup
- remove many obsoletes patch
- do not longer provide update-alternative
- more defined macros in the spec, less hardcode patch

* Tue May 03 2005 Pixel <pixel@mandriva.com> 4.2.3-11mdk
- emacs spec mode:
  - use rpm-find-spec-version-with-shell by default, and enhance it
  - handle release built using mkrel macro (in rpm-increase-release-tag)

* Thu Apr 28 2005 Olivier Thauvin <nanardon@mandriva.org> 4.2.3-10mdk
- split libs into separated package to make rpm update easier for URPM

* Thu Mar 10 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.3-9mdk
- bump multiarch-utils requires
- ignore conflicts in gnome-doc html files, install the latest files

* Wed Mar 09 2005 Frederic Lepied <flepied@mandrakesoft.com> 4.2.3-8mdk
- fix tr call in mono patch (bug #14449)
- fix bzip2 call (bug #7663)
- encode ru man pages in KOI8-R (bug #10219 and #12613)

* Fri Feb 25 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.3-8mdk
- hack to always install the latest arch-independent gtk-doc html
  files and man pages, aka. don't conflict on biarch platforms

* Fri Feb 25 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.3-7mdk
- popt is now a biarch package

* Thu Feb 24 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.3-6mdk
- requires multiarch-utils >= 1.0.7-1mdk
- RPM_INSTALL_LANG support is obsolete for MDK >= 10.2 (rafael)

* Tue Feb 08 2005 Frederic Lepied <flepied@mandrakesoft.com> 4.2.3-5mdk
- added mkrel macro (Buchan)
- changed group System/X11 from System/XFree86

* Thu Jan 27 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.3-4mdk
- newer multiarch-utils requires
- generate package script autoreqs only if requested (#13268)
- don't install .delta.rpm directly, use applydeltarpm first (SuSE)

* Mon Jan 24 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.3-3mdk
- minor cleanups
- check for files that ought to be marked as %%multiarch

* Thu Jan 20 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.3-2mdk
- newer multiarch-utils requires
- enable and improve file coloring
  * use file colors even if still using the external dependencies generator
  * assign a color to *.so symlinks to mix -devel packages
  * assign a color to *.a archives to mix -{static,}-devel packages

* Fri Jan 14 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.3-1mdk
- multiarch-utils autoreq
- allow build of 32-bit RPMs on x86-64
- ppc64 fixes
- update from 4.2-branch
  * auto-relocation fixes on ia64
  * change default behavior to resolve file conflicts as LIFO
  * generate debuginfo for setuid binaries

* Fri Jan 07 2005 Frederic Lepied <flepied@mandrakesoft.com> 4.2.2-19mdk
- compile --with-glob to avoid a problem with the internal glob code.

* Thu Jan 06 2005 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 4.2.2-18mdk
- Add patch 60 (Guillaume Rousse): make find-requires ignore dependencies on
  linux-incompatible perl modules. (bug #12695)

* Mon Dec 06 2004 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 4.2.2-17mdk
- Add patch 59, necessary for the smart package manager (new function
  rpmSingleHeaderFromFD() in the python bindings)

* Sat Dec 04 2004 Frederic Lepied <flepied@mandrakesoft.com> 4.2.2-16mdk
- rebuild for python 2.4

* Fri Aug 06 2004 Frederic Lepied <flepied@mandrakesoft.com> 4.2.2-15mdk
- use system zlib

* Thu Jul 29 2004 Frederic Lepied <flepied@mandrakesoft.com> 4.2.2-14mdk
- fix mono patch (bug #7201)

* Wed Jul 28 2004 Frederic Lepied <flepied@mandrakesoft.com> 4.2.2-13mdk
- use mono-find-requires and mono-find-provides if present (Gtz Waschk) (bug #7201)

* Wed Jul 28 2004 Frederic Lepied <flepied@mandrakesoft.com> 4.2.2-12mdk
- use a correct implementation of cpuid (Gwenole)
- return None instead of [] in rpm-python (Paul Nasrat)
- add /var/spool/repackage (bug #9874)
- handle /usr/lib/gcc/ directories for devel() deps too (Gwenole)

* Thu May 20 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.2-10mdk
- switch back to x86_64 packages on 64-bit extended platforms

* Fri May 14 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 4.2.2-9mdk
- fix /usr/lib/rpmpopt symlink
- use -mtune=pentiumpro on any MDK >= 10.0

* Fri Apr 16 2004 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 4.2.2-8mdk
- When unlocking the RPMLOCK file, don't forget to close(2) it too.

